unit Model;

interface

uses
  Aurelius.Mapping.Attributes, Aurelius.Types.Nullable;

Type
  [AbstractEntity]
  TModelBase = class( TNoRefCountObject )

  end;

  [AbstractEntity]
  [Id('FID', TIdGenerator.IdentityOrSequence)]
  TIDModelBase = class( TModelBase )
  strict private
    [Column('ID', [TColumnProp.Required, TColumnProp.NoInsert, TColumnProp.NoUpdate])]
    FID: Integer;
    procedure SetID(const Value: Integer);
  public
    property ID: Integer read FID write SetID;
  end;

  [AbstractEntity]
  TIDLogModelBase = class( TIDModelBase )
  strict private
    [Column('USER_INS', [], 50)]
    FUSER_INS: Nullable<string>;

    [Column('DATA_INS', [])]
    FDATA_INS: Nullable<TDateTime>;

    [Column('USER_UPD', [], 50)]
    FUSER_UPD: Nullable<string>;

    [Column('DATA_UPD', [])]
    FDATA_UPD: Nullable<TDateTime>;
  public
    property USER_INS: Nullable<string> read FUSER_INS write FUSER_INS;
    property DATA_INS: Nullable<TDateTime> read FDATA_INS write FDATA_INS;
    property USER_UPD: Nullable<string> read FUSER_UPD write FUSER_UPD;
    property DATA_UPD: Nullable<TDateTime> read FDATA_UPD write FDATA_UPD;
  end;

  [AbstractEntity]
  TIDNullableDescription250WithLog= class( TIDLogModelBase )
  strict private
    [Column('DESCRIZIONE', [], 250)]
    FDescrizione: Nullable<string>;
    procedure SetDescription(const Value: Nullable<string>);
  public
    property Descrizione: Nullable<string> read FDescrizione write SetDescription;
  end;

  [Enumeration(TEnumMappingType.emInteger)]
  TSchedulePeriod = ( spHourly, spDaily, spWeekly );
  // un semplice contenitore di info relative al Task schedulato, usato per la transizione dal TaskScheduler ai Task su server REST
  [Entity,Automapping]
  [Table('CMTTASKS')]
  TCMTTASKS = class( TIDNullableDescription250WithLog )
  private
    [Column('TASK', [TColumnProp.Required], 50)]
    FTASK: string;
    [Column('PERIODO',[TColumnProp.Required])]
    FPERIODO: TSchedulePeriod;

    [Column('DATA_INIZIO', [])]
    FDATA_INIZIO: Nullable<TDateTime>;

    [Column('ATTIVO',[],1)]
    FATTIVO: Nullable<string>;

    [Column('LAST_EXEC', [],50)]
    FLAST_EXEC: Nullable<string>;

    [Column('NEXT_EXEC', [],50)]
    FNEXT_EXEC: Nullable<string>;
  public
    property TASK: string read FTASK write FTASK;
    property PERIODO: TSchedulePeriod read FPERIODO WRITE FPERIODO;
    property DATA_INIZIO: Nullable<TDateTime> read FDATA_INIZIO write FDATA_INIZIO;
    property ATTIVO: Nullable<string> read FATTIVO write FATTIVO;
    property LAST_EXEC: Nullable<string> read FLAST_EXEC write FLAST_EXEC;
    property NEXT_EXEC: Nullable<string> read FNEXT_EXEC write FNEXT_EXEC;
  end;

implementation

{ TIDModelBase }

procedure TIDModelBase.SetID(const Value: Integer);
begin
  FID := Value;
end;

{ TIDNullableDescription250WithLog }

procedure TIDNullableDescription250WithLog.SetDescription(
  const Value: Nullable<string>);
begin
  FDescrizione := Value;
end;

initialization
begin
  RegisterEntity(TCMTTASKS);
end;

end.
